msabe: Run the mixed scaling approach in bioequivalence (BE) studies

View source: R/msabe.R View source: R/RcppExports.R

msabeR Documentation

Run the mixed scaling approach in bioequivalence (BE) studies

Description

This function runs hypothesis testing for bioequivalence using the mixed criterion

Usage

msabe(Test, Reference, params = list())

Arguments

Test

An n-by-r matrix of test product data. n is the number of donors and r is the number of skin section replicates.

Reference

An n-by-r matrix of reference product data.

params

(Optional) The list of tuning parameters for running the test.

  • sigma_W0 - A regulatory constant set by the FDA. Defaults to 0.25.

  • m - Another regulatory constant that determines the bounds within which the estimated GMR should fall for bioequivalence to be established. Defaults to 1.25, representing 80-125% average BE limits, which is the FDA recommendation.

  • sig_level - The significance level (alpha-level).

Value

A list of lists

  • parameters - A list of true parameter settings.

  • fout - The test result and related estimators.

  • runtime - The total elapsed time charged for the execution of the program.

Author(s)

Daeyoung Lim, daeyoung.lim@uconn.edu

References

Davit, B. M., Chen, M. L., Conner, D. P., Haidar, S. H., Kim, S., Lee, C. H., Lionberger, R. A., Makhlouf, F. T., Nwakama, P. E., Patel, D. T., Schuirmann, D. J., & Yu, L. X. (2012). Implementation of a reference-scaled average bioequivalence approach for highly variable generic drug products by the US Food and Drug Administration. The AAPS journal, 14(4), 915-924.

Examples

n <- 6
r <- 3
Test <- matrix(runif(n*r), nrow = n, ncol = r)
Reference <- matrix(runif(n*r), nrow = n, ncol = r)
out <- msabe(Test, Reference)


adaptIVPT documentation built on May 29, 2024, 12:02 p.m.

Related to msabe in adaptIVPT...